@@ -50,7 +50,7 @@
 #' res_custom_map(stations = stns, x_loc = x_coords, y_loc = y_coords,
 #' bbox = bounding_elk, lab_loc = lab_dir, scale_pos = pos, shp = shp_fl)
 #'
-#' \dontrun{
+#' \donttest{
 #' res_custom_map(stations = stns, x_loc = x_coords, y_loc = y_coords,
 #' bbox = bounding_elk, lab_loc = lab_dir, scale_pos = pos,
 #' shp = shp_fl, station_col = c('red', 'green'))
@@ -103,15 +103,15 @@ res_custom_map <- function(stations
   )
 
   # generate location labels
-  loc <- data.frame(abbrev = stations, Latitude = y_loc, Longitude = -1 * x_loc, color = station_col, stringsAsFactors = F)
+  loc <- data.frame(abbrev = stations, Latitude = y_loc, Longitude = -1 * x_loc, color = station_col, stringsAsFactors = FALSE)
 
   # Determine if r and l labs exist
   if(!is.null(lab_loc)){
-    left_labs <- grep('L', lab_loc)
-    right_labs <- grep('R', lab_loc)
+    if('L' %in% lab_loc){left_labs <- grep('L', lab_loc)}
+    if('R' %in% lab_loc){right_labs <- grep('R', lab_loc)}
   } else {
     #default to left labels
-    left_labs <- rep('L', length(stations))
+    left_labs <- c(1:4)
   }
 
   # Plot map
@@ -119,7 +119,7 @@ res_custom_map <- function(stations
     addProviderTiles(leaflet::providers$Esri.WorldGrayCanvas) %>%  # Add default OpenStreetMap map tiles, CartoDB.Positron
     addPolygons(data = shp, weight = 2, color = '#B3B300', fillColor = 'yellow')
 
-  if(length(left_labs) > 0){
+  if(exists('left_labs')){
     m <- m %>%
       addCircleMarkers(lng = ~Longitude[left_labs] * -1, lat = ~Latitude[left_labs], radius = 5
                        , weight = 0, fillOpacity = 1
@@ -132,7 +132,7 @@ res_custom_map <- function(stations
                                                      , style = label_style))
   }
 
-  if(length(right_labs) > 0){
+  if(exists('right_labs')){
     m <- m %>%
       addCircleMarkers(lng = ~Longitude[right_labs] * -1, lat = ~Latitude[right_labs], radius = 5
                        , weight = 0, fillOpacity = 1
